@@ -23,6 +23,7 @@ from scalekit.actions import ActionClient
 from scalekit.passwordless import PasswordlessClient
 from scalekit.mcp import McpClient
 from scalekit.sessions import SessionsClient
+from scalekit.auth import AuthClient
 from scalekit.common.scalekit import (
     AuthorizationUrlOptions,
     CodeAuthenticationOptions,
@@ -76,6 +77,7 @@ class ScalekitClient:
             self.actions = ActionClient(self.tools, self.connected_accounts, self.mcp)
             self.passwordless = PasswordlessClient(self.core_client)
             self.sessions = SessionsClient(self.core_client)
+            self.auth = AuthClient(self.core_client)
         except Exception as exp:
             raise exp
 
@@ -153,7 +155,7 @@ class ScalekitClient:
             access_token = response["access_token"]
             refresh_token = response.get("refresh_token")
             # Validate id_token
-            claims = self.__validate_token(id_token, options=None)
+            claims = self.validate_token(id_token, options=None)
             user = {}
             amr_claims = claims.get('amr', [])
             connection_id = amr_claims[0] if amr_claims else None
